@@ -2013,6 +2013,23 @@ EAPI Eina_Bool edje_object_part_text_cursor_is_format_get(const Edje_Object *obj
  */
 EAPI Eina_Bool edje_object_text_class_get(const Edje_Object *obj, const char *text_class, const char **font, Evas_Font_Size *size);
 
+/**
+ * @brief Delete the object text class.
+ *
+ * This function deletes any values at the object level for the specified
+ * object and text class.
+ *
+ * Deleting the text class will revert it to the values defined by
+ * edje_text_class_set() or the text class defined in the theme file.
+ *
+ * @param[in] text_class The color class to be deleted.
+ *
+ * @since 1.17
+ *
+ * @ingroup Edje_Object
+ */
+EAPI void edje_object_text_class_del(Edje_Object *obj, const char *text_class);
+
 /**
  * @brief Sets the object color class.
  *
@@ -2090,6 +2107,92 @@ EAPI Eina_Bool edje_object_color_class_get(const Edje_Object *obj, const char *c
  */
 EAPI const char *edje_object_color_class_description_get(const Edje_Object *obj, const char *color_class);
 
+/**
+ * @brief Clear object color classes.
+ *
+ * @return @c true, on success or @c false, on error
+ *
+ * @since 1.17.0
+ *
+ * @ingroup Edje_Object
+ */
+EAPI Eina_Bool edje_object_color_class_clear(const Edje_Object *obj);
+
+/**
+ * @brief Delete the object color class.
+ *
+ * This function deletes any values at the object level for the specified
+ * object and color class.
+ *
+ * Deleting the color class will revert it to the values defined by
+ * edje_color_class_set() or the color class defined in the theme file.
+ *
+ * Deleting the color class will emit the signal "color_class,del" for the
+ * given Edje object.
+ *
+ * @param[in] color_class The color class to be deleted.
+ *
+ * @ingroup Edje_Object
+ */
+EAPI void edje_object_color_class_del(Edje_Object *obj, const char *color_class);
+
+/**
+ * @brief Sets the object size class.
+ *
+ * This function sets the min and max values for an object level size class.
+ * This will make all edje parts in the specified object that have the
+ * specified size class update their min and max size with given values.
+ *
+ * @param[in] minw The min width
+ * @param[in] minh The min height
+ * @param[in] maxw The max width
+ * @param[in] maxh The max height
+ *
+ * @return @c true, on success or @c false, on error
+ *
+ * @since 1.17
+ *
+ * @ingroup Edje_Object
+ */
+EAPI Eina_Bool edje_object_size_class_set(Edje_Object *obj, const char *size_class, int minw, int minh, int maxw, int maxh);
+
+/**
+ * @brief Gets the object size class.
+ *
+ * This function gets the min and max values for an object level size class.
+ * These values will only be valid until the size class is changed or the edje
+ * object is deleted.
+ *
+ * @param[out] minw The min width
+ * @param[out] minh The min height
+ * @param[out] maxw The max width
+ * @param[out] maxh The max height
+ *
+ * @return @c true, on success or @c false, on error
+ *
+ * @since 1.17
+ *
+ * @ingroup Edje_Object
+ */
+EAPI Eina_Bool edje_object_size_class_get(const Edje_Object *obj, const char *size_class, int *minw, int *minh, int *maxw, int *maxh);
+
+/**
+ * @brief Delete the object size class.
+ *
+ * This function deletes any values at the object level for the specified
+ * object and size class.
+ *
+ * Deleting the size class will revert it to the values defined by
+ * edje_size_class_set() or the color class defined in the theme file.
+ *
+ * @param[in] size_class
+ *
+ * @since 1.17
+ *
+ * @ingroup Edje_Object
+ */
+EAPI void edje_object_size_class_del(Edje_Object *obj, const char *size_class);
+
 /**
  * @brief Steps the dragable x,y steps.
  *
