@@ -34,7 +34,7 @@ EAPI const Eo_Class *evas_object_class_get(void) EINA_CONST;
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_max_set(Evas_Coord w, Evas_Coord h);
+EOAPI void evas_obj_size_hint_max_set(Evas_Coord w, Evas_Coord h);
 
 /**
  * @brief Retrieves the hints for an object's maximum size.
@@ -51,7 +51,7 @@ EOAPI void  evas_obj_size_hint_max_set(Evas_Coord w, Evas_Coord h);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_max_get(Evas_Coord *w, Evas_Coord *h);
+EOAPI void evas_obj_size_hint_max_get(Evas_Coord *w, Evas_Coord *h);
 
 /**
  * @brief Sets the hints for an object's optimum size.
@@ -69,7 +69,7 @@ EOAPI void  evas_obj_size_hint_max_get(Evas_Coord *w, Evas_Coord *h);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_request_set(Evas_Coord w, Evas_Coord h);
+EOAPI void evas_obj_size_hint_request_set(Evas_Coord w, Evas_Coord h);
 
 /**
  * @brief Retrieves the hints for an object's optimum size.
@@ -86,7 +86,7 @@ EOAPI void  evas_obj_size_hint_request_set(Evas_Coord w, Evas_Coord h);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_request_get(Evas_Coord *w, Evas_Coord *h);
+EOAPI void evas_obj_size_hint_request_get(Evas_Coord *w, Evas_Coord *h);
 
 /**
  * @brief Sets the type of the given Evas object.
@@ -95,7 +95,7 @@ EOAPI void  evas_obj_size_hint_request_get(Evas_Coord *w, Evas_Coord *h);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_type_set(const char *type);
+EOAPI void evas_obj_type_set(const char *type);
 
 /**
  * @brief Retrieves the type of the given Evas object.
@@ -113,7 +113,7 @@ EOAPI void  evas_obj_type_set(const char *type);
  *
  * @ingroup Evas_Object
  */
-EOAPI const char * evas_obj_type_get(void);
+EOAPI const char *evas_obj_type_get(void);
 
 /**
  * @brief Sets the hints for an object's minimum size.
@@ -131,7 +131,7 @@ EOAPI const char * evas_obj_type_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_min_set(Evas_Coord w, Evas_Coord h);
+EOAPI void evas_obj_size_hint_min_set(Evas_Coord w, Evas_Coord h);
 
 /**
  * @brief Retrieves the hints for an object's minimum size.
@@ -148,7 +148,7 @@ EOAPI void  evas_obj_size_hint_min_set(Evas_Coord w, Evas_Coord h);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_min_get(Evas_Coord *w, Evas_Coord *h);
+EOAPI void evas_obj_size_hint_min_get(Evas_Coord *w, Evas_Coord *h);
 
 /**
  * @brief Set pointer behavior.
@@ -168,7 +168,7 @@ EOAPI void  evas_obj_size_hint_min_get(Evas_Coord *w, Evas_Coord *h);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_pointer_mode_set(Evas_Object_Pointer_Mode pointer_mode);
+EOAPI void evas_obj_pointer_mode_set(Evas_Object_Pointer_Mode pointer_mode);
 
 /**
  * @brief Determine how pointer will behave.
@@ -177,26 +177,40 @@ EOAPI void  evas_obj_pointer_mode_set(Evas_Object_Pointer_Mode pointer_mode);
  *
  * @ingroup Evas_Object
  */
-EOAPI Evas_Object_Pointer_Mode  evas_obj_pointer_mode_get(void);
+EOAPI Evas_Object_Pointer_Mode evas_obj_pointer_mode_get(void);
 
 /**
- * @brief Sets the render_op to be used for rendering the Evas object.
+ * @brief Sets the render mode to be used for compositing the Evas object.
  *
- * @param[in] render_op One of the Evas_Render_Op values.
+ * Note that only copy and blend modes are actually supported: -
+ * @ref Evas_Render_Op.EVAS_RENDER_BLEND means the object will be merged on top
+ * of objects below it using simple alpha compositing. -
+ * @ref Evas_Render_Op.EVAS_RENDER_COPY means this object's pixels will replace
+ * everything that is below, making this object opaque.
+ *
+ * Please do not assume that @ref Evas_Render_Op.EVAS_RENDER_COPY mode can be
+ * used to "poke" holes in a window (to see through it), as only the compositor
+ * can ensure that. Copy mode should only be used with otherwise opaque
+ * widgets, or inside non-window surfaces (eg. a transparent background inside
+ * an Ecore.Evas.Buffer).
+ *
+ * @param[in] render_op One of the Evas_Render_Op values. Only blend (default)
+ * and copy modes are supported.
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_render_op_set(Evas_Render_Op render_op);
+EOAPI void evas_obj_render_op_set(Evas_Render_Op render_op);
 
 /**
  * @brief Retrieves the current value of the operation used for rendering the
  * Evas object.
  *
- * @return One of the Evas_Render_Op values.
+ * @return One of the Evas_Render_Op values. Only blend (default) and copy
+ * modes are supported.
  *
  * @ingroup Evas_Object
  */
-EOAPI Evas_Render_Op  evas_obj_render_op_get(void);
+EOAPI Evas_Render_Op evas_obj_render_op_get(void);
 
 /**
  * @brief Set whether an Evas object is to freeze (discard) events.
@@ -219,7 +233,7 @@ EOAPI Evas_Render_Op  evas_obj_render_op_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_freeze_events_set(Eina_Bool freeze);
+EOAPI void evas_obj_freeze_events_set(Eina_Bool freeze);
 
 /**
  * @brief Determine whether an object is set to freeze (discard) events.
@@ -230,7 +244,7 @@ EOAPI void  evas_obj_freeze_events_set(Eina_Bool freeze);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_freeze_events_get(void);
+EOAPI Eina_Bool evas_obj_freeze_events_get(void);
 
 /**
  * @brief Set current object transformation map.
@@ -254,7 +268,7 @@ EOAPI Eina_Bool  evas_obj_freeze_events_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_map_set(const Evas_Map *map);
+EOAPI void evas_obj_map_set(const Evas_Map *map);
 
 /**
  * @brief Get current object transformation map.
@@ -267,7 +281,7 @@ EOAPI void  evas_obj_map_set(const Evas_Map *map);
  *
  * @ingroup Evas_Object
  */
-EOAPI const Evas_Map * evas_obj_map_get(void);
+EOAPI const Evas_Map *evas_obj_map_get(void);
 
 /**
  * @brief Sets the hints for an object's aspect ratio.
@@ -288,7 +302,7 @@ EOAPI const Evas_Map * evas_obj_map_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_aspect_set(Evas_Aspect_Control aspect, Evas_Coord w, Evas_Coord h);
+EOAPI void evas_obj_size_hint_aspect_set(Evas_Aspect_Control aspect, Evas_Coord w, Evas_Coord h);
 
 /**
  * @brief Retrieves the hints for an object's aspect ratio.
@@ -311,7 +325,7 @@ EOAPI void  evas_obj_size_hint_aspect_set(Evas_Aspect_Control aspect, Evas_Coord
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_aspect_get(Evas_Aspect_Control *aspect, Evas_Coord *w, Evas_Coord *h);
+EOAPI void evas_obj_size_hint_aspect_get(Evas_Aspect_Control *aspect, Evas_Coord *w, Evas_Coord *h);
 
 /**
  * @brief Clip one object to another.
@@ -352,7 +366,7 @@ EOAPI void  evas_obj_size_hint_aspect_get(Evas_Aspect_Control *aspect, Evas_Coor
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_clip_set(Evas_Object *clip);
+EOAPI void evas_obj_clip_set(Evas_Object *clip);
 
 /**
  * @brief Get the object clipping @c obj (if any).
@@ -365,7 +379,7 @@ EOAPI void  evas_obj_clip_set(Evas_Object *clip);
  *
  * @ingroup Evas_Object
  */
-EOAPI Evas_Object * evas_obj_clip_get(void);
+EOAPI Evas_Object *evas_obj_clip_get(void);
 
 /**
  * @brief Sets the hints for an object's padding space.
@@ -383,7 +397,7 @@ EOAPI Evas_Object * evas_obj_clip_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_padding_set(Evas_Coord l, Evas_Coord r, Evas_Coord t, Evas_Coord b);
+EOAPI void evas_obj_size_hint_padding_set(Evas_Coord l, Evas_Coord r, Evas_Coord t, Evas_Coord b);
 
 /**
  * @brief Retrieves the hints for an object's padding space.
@@ -404,7 +418,7 @@ EOAPI void  evas_obj_size_hint_padding_set(Evas_Coord l, Evas_Coord r, Evas_Coor
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_padding_get(Evas_Coord *l, Evas_Coord *r, Evas_Coord *t, Evas_Coord *b);
+EOAPI void evas_obj_size_hint_padding_get(Evas_Coord *l, Evas_Coord *r, Evas_Coord *t, Evas_Coord *b);
 
 /**
  * @brief Set whether an Evas object is to repeat events.
@@ -421,7 +435,7 @@ EOAPI void  evas_obj_size_hint_padding_get(Evas_Coord *l, Evas_Coord *r, Evas_Co
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_repeat_events_set(Eina_Bool repeat);
+EOAPI void evas_obj_repeat_events_set(Eina_Bool repeat);
 
 /**
  * @brief Determine whether an object is set to repeat events.
@@ -430,7 +444,7 @@ EOAPI void  evas_obj_repeat_events_set(Eina_Bool repeat);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_repeat_events_get(void);
+EOAPI Eina_Bool evas_obj_repeat_events_get(void);
 
 /**
  * @brief Sets the hints for an object's weight.
@@ -455,7 +469,7 @@ EOAPI Eina_Bool  evas_obj_repeat_events_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_weight_set(double x, double y);
+EOAPI void evas_obj_size_hint_weight_set(double x, double y);
 
 /**
  * @brief Retrieves the hints for an object's weight.
@@ -478,7 +492,7 @@ EOAPI void  evas_obj_size_hint_weight_set(double x, double y);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_weight_get(double *x, double *y);
+EOAPI void evas_obj_size_hint_weight_get(double *x, double *y);
 
 /**
  * @brief Sets the name of the given Evas object to the given name.
@@ -489,7 +503,7 @@ EOAPI void  evas_obj_size_hint_weight_get(double *x, double *y);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_name_set(const char *name);
+EOAPI void evas_obj_name_set(const char *name);
 
 /**
  * @brief Retrieves the name of the given Evas object.
@@ -500,7 +514,7 @@ EOAPI void  evas_obj_name_set(const char *name);
  *
  * @ingroup Evas_Object
  */
-EOAPI const char * evas_obj_name_get(void);
+EOAPI const char *evas_obj_name_get(void);
 
 /**
  * @brief Sets the scaling factor for an Evas object. Does not affect all
@@ -517,7 +531,7 @@ EOAPI const char * evas_obj_name_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_scale_set(double scale);
+EOAPI void evas_obj_scale_set(double scale);
 
 /**
  * @brief Retrieves the scaling factor for the given Evas object.
@@ -526,7 +540,7 @@ EOAPI void  evas_obj_scale_set(double scale);
  *
  * @ingroup Evas_Object
  */
-EOAPI double  evas_obj_scale_get(void);
+EOAPI double evas_obj_scale_get(void);
 
 /**
  * @brief Set a hint flag on the given Evas object that it's used as a "static
@@ -541,7 +555,7 @@ EOAPI double  evas_obj_scale_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_static_clip_set(Eina_Bool is_static_clip);
+EOAPI void evas_obj_static_clip_set(Eina_Bool is_static_clip);
 
 /**
  * @brief Get the "static clipper" hint flag for a given Evas object.
@@ -550,7 +564,7 @@ EOAPI void  evas_obj_static_clip_set(Eina_Bool is_static_clip);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_static_clip_get(void);
+EOAPI Eina_Bool evas_obj_static_clip_get(void);
 
 /**
  * @brief Sets or unsets a given object as the currently focused one on its
@@ -567,7 +581,7 @@ EOAPI Eina_Bool  evas_obj_static_clip_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_focus_set(Eina_Bool focus);
+EOAPI void evas_obj_focus_set(Eina_Bool focus);
 
 /**
  * @brief Retrieve whether an object has the focus.
@@ -579,7 +593,7 @@ EOAPI void  evas_obj_focus_set(Eina_Bool focus);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_focus_get(void);
+EOAPI Eina_Bool evas_obj_focus_get(void);
 
 /**
  * @brief No description supplied.
@@ -590,7 +604,7 @@ EOAPI Eina_Bool  evas_obj_focus_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_is_frame_object_set(Eina_Bool is_frame);
+EOAPI void evas_obj_is_frame_object_set(Eina_Bool is_frame);
 
 /** No description supplied.
  *
@@ -598,7 +612,7 @@ EOAPI void  evas_obj_is_frame_object_set(Eina_Bool is_frame);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_is_frame_object_get(void);
+EOAPI Eina_Bool evas_obj_is_frame_object_get(void);
 
 /**
  * @brief Enable or disable the map that is set.
@@ -615,7 +629,7 @@ EOAPI Eina_Bool  evas_obj_is_frame_object_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_map_enable_set(Eina_Bool enabled);
+EOAPI void evas_obj_map_enable_set(Eina_Bool enabled);
 
 /**
  * @brief Get the map enabled state
@@ -628,7 +642,7 @@ EOAPI void  evas_obj_map_enable_set(Eina_Bool enabled);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_map_enable_get(void);
+EOAPI Eina_Bool evas_obj_map_enable_get(void);
 
 /**
  * @brief Set whether to use precise (usually expensive) point collision
@@ -646,7 +660,7 @@ EOAPI Eina_Bool  evas_obj_map_enable_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_precise_is_inside_set(Eina_Bool precise);
+EOAPI void evas_obj_precise_is_inside_set(Eina_Bool precise);
 
 /**
  * @brief Determine whether an object is set to use precise point collision
@@ -657,7 +671,7 @@ EOAPI void  evas_obj_precise_is_inside_set(Eina_Bool precise);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_precise_is_inside_get(void);
+EOAPI Eina_Bool evas_obj_precise_is_inside_get(void);
 
 /**
  * @brief Sets the hints for an object's alignment.
@@ -688,7 +702,7 @@ EOAPI Eina_Bool  evas_obj_precise_is_inside_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_align_set(double x, double y);
+EOAPI void evas_obj_size_hint_align_set(double x, double y);
 
 /**
  * @brief Retrieves the hints for on object's alignment.
@@ -708,7 +722,7 @@ EOAPI void  evas_obj_size_hint_align_set(double x, double y);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_align_get(double *x, double *y);
+EOAPI void evas_obj_size_hint_align_get(double *x, double *y);
 
 /**
  * @brief Set whether events on a smart object's member should get propagated
@@ -728,7 +742,7 @@ EOAPI void  evas_obj_size_hint_align_get(double *x, double *y);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_propagate_events_set(Eina_Bool propagate);
+EOAPI void evas_obj_propagate_events_set(Eina_Bool propagate);
 
 /**
  * @brief Retrieve whether an Evas object is set to propagate events.
@@ -740,7 +754,7 @@ EOAPI void  evas_obj_propagate_events_set(Eina_Bool propagate);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_propagate_events_get(void);
+EOAPI Eina_Bool evas_obj_propagate_events_get(void);
 
 /**
  * @brief Set whether an Evas object is to pass (ignore) events.
@@ -758,7 +772,7 @@ EOAPI Eina_Bool  evas_obj_propagate_events_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_pass_events_set(Eina_Bool pass);
+EOAPI void evas_obj_pass_events_set(Eina_Bool pass);
 
 /**
  * @brief Determine whether an object is set to pass (ignore) events.
@@ -770,7 +784,7 @@ EOAPI void  evas_obj_pass_events_set(Eina_Bool pass);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_pass_events_get(void);
+EOAPI Eina_Bool evas_obj_pass_events_get(void);
 
 /**
  * @brief Sets whether or not the given Evas object is to be drawn
@@ -781,7 +795,7 @@ EOAPI Eina_Bool  evas_obj_pass_events_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_anti_alias_set(Eina_Bool anti_alias);
+EOAPI void evas_obj_anti_alias_set(Eina_Bool anti_alias);
 
 /**
  * @brief Retrieves whether or not the given Evas object is to be drawn
@@ -791,7 +805,7 @@ EOAPI void  evas_obj_anti_alias_set(Eina_Bool anti_alias);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_anti_alias_get(void);
+EOAPI Eina_Bool evas_obj_anti_alias_get(void);
 
 /**
  * @brief Retrieve user data stored on a given smart object.
@@ -800,7 +814,7 @@ EOAPI Eina_Bool  evas_obj_anti_alias_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void * evas_obj_smart_data_get(void);
+EOAPI void *evas_obj_smart_data_get(void);
 
 /**
  * @brief Get the clipper object for the given clipped smart object.
@@ -810,7 +824,7 @@ EOAPI void * evas_obj_smart_data_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI Evas_Object * evas_obj_smart_clipped_clipper_get(void);
+EOAPI Evas_Object *evas_obj_smart_clipped_clipper_get(void);
 
 /**
  * @brief Return a list of objects currently clipped by @c obj.
@@ -832,7 +846,7 @@ EOAPI Evas_Object * evas_obj_smart_clipped_clipper_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI const Eina_List * evas_obj_clipees_get(void);
+EOAPI const Eina_List *evas_obj_clipees_get(void);
 
 /**
  * @brief Gets the parent smart object of a given Evas object, if it has one.
@@ -841,7 +855,7 @@ EOAPI const Eina_List * evas_obj_clipees_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI Evas_Object * evas_obj_smart_parent_get(void);
+EOAPI Evas_Object *evas_obj_smart_parent_get(void);
 
 /**
  * @brief Sets the hints for an object's disply mode,
@@ -853,7 +867,7 @@ EOAPI Evas_Object * evas_obj_smart_parent_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_size_hint_display_mode_set(Evas_Display_Mode dispmode);
+EOAPI void evas_obj_size_hint_display_mode_set(Evas_Display_Mode dispmode);
 
 /**
  * @brief Retrieves the hints for an object's display mode
@@ -866,7 +880,31 @@ EOAPI void  evas_obj_size_hint_display_mode_set(Evas_Display_Mode dispmode);
  *
  * @ingroup Evas_Object
  */
-EOAPI Evas_Display_Mode  evas_obj_size_hint_display_mode_get(void);
+EOAPI Evas_Display_Mode evas_obj_size_hint_display_mode_get(void);
+
+/**
+ * @brief This handles text paragraph direction of the given object. Even if
+ * the given object is not textblock or text, its smart child objects can
+ * inherit the paragraph direction from the given object. The default paragraph
+ * direction is @ref Evas_BiDi_Direction.EVAS_BIDI_DIRECTION_INHERIT.
+ *
+ * @param[in] dir Paragraph direction for the given object.
+ *
+ * @ingroup Evas_Object
+ */
+EOAPI void evas_obj_paragraph_direction_set(Evas_BiDi_Direction dir);
+
+/**
+ * @brief This handles text paragraph direction of the given object. Even if
+ * the given object is not textblock or text, its smart child objects can
+ * inherit the paragraph direction from the given object. The default paragraph
+ * direction is @ref Evas_BiDi_Direction.EVAS_BIDI_DIRECTION_INHERIT.
+ *
+ * @return Paragraph direction for the given object.
+ *
+ * @ingroup Evas_Object
+ */
+EOAPI Evas_BiDi_Direction evas_obj_paragraph_direction_get(void);
 
 /**
  * @brief Disable all rendering on the canvas.
@@ -889,7 +927,7 @@ EOAPI Evas_Display_Mode  evas_obj_size_hint_display_mode_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_no_render_set(Eina_Bool enable);
+EOAPI void evas_obj_no_render_set(Eina_Bool enable);
 
 /**
  * @brief Returns the state of the "no-render" flag, which means, when true,
@@ -904,7 +942,7 @@ EOAPI void  evas_obj_no_render_set(Eina_Bool enable);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_no_render_get(void);
+EOAPI Eina_Bool evas_obj_no_render_get(void);
 
 /** Test if any object is clipped by @c obj.
  *
@@ -912,7 +950,7 @@ EOAPI Eina_Bool  evas_obj_no_render_get(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_clipees_has(void);
+EOAPI Eina_Bool evas_obj_clipees_has(void);
 
 /**
  * @brief Requests @c keyname key events be directed to @c obj.
@@ -950,7 +988,7 @@ EOAPI Eina_Bool  evas_obj_clipees_has(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_key_grab(const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers, Eina_Bool exclusive);
+EOAPI Eina_Bool evas_obj_key_grab(const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers, Eina_Bool exclusive);
 
 /**
  * @brief Checks whether a given smart object or any of its smart object
@@ -972,7 +1010,7 @@ EOAPI Eina_Bool  evas_obj_key_grab(const char *keyname, Evas_Modifier_Mask modif
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_smart_type_check(const char *type);
+EOAPI Eina_Bool evas_obj_smart_type_check(const char *type);
 
 /**
  * @brief Retrieves the object from children of the given object with the given
@@ -995,7 +1033,7 @@ EOAPI Eina_Bool  evas_obj_smart_type_check(const char *type);
  *
  * @ingroup Evas_Object
  */
-EOAPI Evas_Object * evas_obj_name_child_find(const char *name, int recurse);
+EOAPI Evas_Object *evas_obj_name_child_find(const char *name, int recurse);
 
 /**
  * @brief Removes the grab on @c keyname key events by @c obj.
@@ -1013,7 +1051,7 @@ EOAPI Evas_Object * evas_obj_name_child_find(const char *name, int recurse);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_key_ungrab(const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers);
+EOAPI void evas_obj_key_ungrab(const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers);
 
 /**
  * @brief Disable/cease clipping on a clipped @c obj object.
@@ -1028,7 +1066,7 @@ EOAPI void  evas_obj_key_ungrab(const char *keyname, Evas_Modifier_Mask modifier
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_clip_unset(void);
+EOAPI void evas_obj_clip_unset(void);
 
 /**
  * @brief Moves all children objects of a given smart object relative to a
@@ -1046,7 +1084,7 @@ EOAPI void  evas_obj_clip_unset(void);
  *
  * @ingroup Evas_Object
  */
-EOAPI void  evas_obj_smart_move_children_relative(Evas_Coord dx, Evas_Coord dy);
+EOAPI void evas_obj_smart_move_children_relative(Evas_Coord dx, Evas_Coord dy);
 
 /**
  * @brief Checks whether a given smart object or any of its smart object
@@ -1059,7 +1097,7 @@ EOAPI void  evas_obj_smart_move_children_relative(Evas_Coord dx, Evas_Coord dy);
  *
  * @ingroup Evas_Object
  */
-EOAPI Eina_Bool  evas_obj_smart_type_check_ptr(const char *type);
+EOAPI Eina_Bool evas_obj_smart_type_check_ptr(const char *type);
 
 EOAPI extern const Eo_Event_Description _EVAS_OBJECT_EVENT_MOUSE_IN;
 EOAPI extern const Eo_Event_Description _EVAS_OBJECT_EVENT_MOUSE_OUT;
