@@ -44,18 +44,24 @@ typedef enum
  */
 typedef enum
 {
-  EVAS_RENDER_BLEND = 0, /** default op: d = d*(1-sa) + s */
-  EVAS_RENDER_BLEND_REL = 1, /** d = d*(1 - sa) + s*da */
-  EVAS_RENDER_COPY = 2, /** d = s */
-  EVAS_RENDER_COPY_REL = 3, /** d = s*da */
-  EVAS_RENDER_ADD = 4, /** d = d + s */
-  EVAS_RENDER_ADD_REL = 5, /** d = d + s*da */
-  EVAS_RENDER_SUB = 6, /** d = d - s */
-  EVAS_RENDER_SUB_REL = 7, /** d = d - s*da */
-  EVAS_RENDER_TINT = 8, /** d = d*s + d*(1 - sa) + s*(1 - da) */
-  EVAS_RENDER_TINT_REL = 9, /** d = d*(1 - sa + s) */
-  EVAS_RENDER_MASK = 10, /** d = d*sa */
-  EVAS_RENDER_MUL = 11 /** d = d*s */
+  EVAS_RENDER_BLEND = 0, /** Default render operation: d = d*(1-sa) + s. The
+                          * object will be merged onto the bottom objects using
+                          * simple alpha compositing (a over b). */
+  EVAS_RENDER_BLEND_REL = 1, /** DEPRECATED. d = d*(1 - sa) + s*da */
+  EVAS_RENDER_COPY = 2, /** Copy mode, d = s. The object's pixels will replace
+                         * everything that was below, effectively hiding them.
+                         */
+  EVAS_RENDER_COPY_REL = 3, /** DEPRECATED. d = s*da */
+  EVAS_RENDER_ADD = 4, /** DEPRECATED. d = d + s */
+  EVAS_RENDER_ADD_REL = 5, /** DEPRECATED. d = d + s*da */
+  EVAS_RENDER_SUB = 6, /** DEPRECATED. d = d - s */
+  EVAS_RENDER_SUB_REL = 7, /** DEPRECATED. d = d - s*da */
+  EVAS_RENDER_TINT = 8, /** DEPRECATED. d = d*s + d*(1 - sa) + s*(1 - da) */
+  EVAS_RENDER_TINT_REL = 9, /** DEPRECATED. d = d*(1 - sa + s) */
+  EVAS_RENDER_MASK = 10, /** DEPRECATED. d = d*sa. For masking support, please
+                          * use Evas.Object.clip_set or EDC "clip_to" instead.
+                          */
+  EVAS_RENDER_MUL = 11 /** DEPRECATED. d = d*s */
 } Evas_Render_Op;
 
 /**
@@ -105,7 +111,8 @@ typedef enum
   EVAS_BIDI_DIRECTION_NATURAL = 0,
   EVAS_BIDI_DIRECTION_NEUTRAL = 0,
   EVAS_BIDI_DIRECTION_LTR,
-  EVAS_BIDI_DIRECTION_RTL
+  EVAS_BIDI_DIRECTION_RTL,
+  EVAS_BIDI_DIRECTION_INHERIT
 } Evas_BiDi_Direction;
 
 /** Types of styles to be applied on text objects. The
@@ -250,10 +257,13 @@ typedef enum
   EVAS_CALLBACK_IMAGE_PRELOADED, /** Image has been preloaded */
   EVAS_CALLBACK_CANVAS_FOCUS_IN, /** Canvas got focus as a whole */
   EVAS_CALLBACK_CANVAS_FOCUS_OUT, /** Canvas lost focus as a whole */
-  EVAS_CALLBACK_RENDER_FLUSH_PRE, /** Called just before rendering is updated
-                                   * on the canvas target */
-  EVAS_CALLBACK_RENDER_FLUSH_POST, /** Called just after rendering is updated
-                                    * on the canvas target */
+  EVAS_CALLBACK_RENDER_FLUSH_PRE, /** Called after render update regions have
+                                   * been calculated, but only if update
+                                   * regions exist */
+  EVAS_CALLBACK_RENDER_FLUSH_POST, /** Called after render update regions have
+                                    * been sent to the display server, but only
+                                    * if update regions existed for the most
+                                    * recent frame */
   EVAS_CALLBACK_CANVAS_OBJECT_FOCUS_IN, /** Canvas object got focus */
   EVAS_CALLBACK_CANVAS_OBJECT_FOCUS_OUT, /** Canvas object lost focus */
   EVAS_CALLBACK_IMAGE_UNLOADED, /** Image data has been unloaded (by some
